@@ -36,6 +36,7 @@ OC.L10N.register(
     "List view" : "Lysaansig",
     "Actions" : "Aksies",
     "Show week numbers" : "Toon weeknommers",
+    "Update" : "Werk by",
     "Location" : "Ligging",
     "Description" : "Beskrywing",
     "Duration" : "Duur",
@@ -48,10 +49,14 @@ OC.L10N.register(
     "Friday" : "Vrydag",
     "Saturday" : "Saterdag",
     "Sunday" : "Sondag",
-    "Update" : "Werk by",
     "Your email address" : "U e-posadres",
     "Notification" : "Kennisgewing",
     "Email" : "E-pos",
+    "seconds" : "sekondes",
+    "minutes" : "minute",
+    "hours" : "uur",
+    "days" : "dae",
+    "weeks" : "weke",
     "Delete file" : "Skrap lêer",
     "Available" : "Beskikbaar",
     "Not available" : "Onbeskikbaar",
@@ -61,21 +66,21 @@ OC.L10N.register(
     "Attendees" : "Bywoners",
     "From" : "Van",
     "To" : "Aan",
-    "All day" : "Heeldag",
     "Repeat" : "Herhaal",
     "never" : "nooit",
     "after" : "na",
+    "Resources" : "Hulpbronne",
     "available" : "beskikbaar",
     "Global" : "Globaal",
     "Subscribe" : "Teken in",
     "Personal" : "Persoonlik",
-    "Details" : "Details",
-    "Resources" : "Hulpbronne",
+    "All day" : "Heeldag",
     "Close" : "Sluit",
     "Anniversary" : "Herdenking",
     "Week {number} of {year}" : "Week {number} van {year}",
     "Daily" : "Daagliks",
     "Weekly" : "Weekliks",
+    "second" : "sekonde",
     "Other" : "Ander",
     "Status" : "Status",
     "Confirmed" : "Bevestig",
