@@ -268,7 +268,6 @@ OC.L10N.register(
     "Add Talk conversation" : "إضِف محادثة Talk",
     "Fetching Talk rooms…" : "جلب معلومات غرف المحادثة ...",
     "No Talk room available" : "لاتوجد غرف محادثة متاحة",
-    "Create a new conversation" : "إنشاء محادثة جديدة",
     "Select conversation" : "اختر محادثة",
     "on" : "في",
     "at" : "عند",
@@ -440,7 +439,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "لا توجد أيّ تقاويم عمومية مُهيّأة بالشكل الصحيح",
     "Speak to the server administrator to resolve this issue." : "تحدّث مع مسؤول النظام لحل هذا الإشكال.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "يتم توفير تقاويم العطلات العامة من موقع ثندربرد Thunderbird. سوف يتم تنزيل بيانات التقويم من {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "يتم اقتراح هذه التقويمات العامة بواسطة مسؤول القسم. سيتم تنزيل بيانات التقويم من موقع الويب المعني.",
     "By {authors}" : "من قِبَل {authors}",
     "Subscribed" : "مشترك",
     "Subscribe" : "إشترك",
@@ -578,13 +576,6 @@ OC.L10N.register(
     "This is an event reminder." : "هذا تذكير بحدث",
     "Error while parsing a PROPFIND error" : "حدث خطأ أثناء تحليل PROFIND",
     "Appointment not found" : "الموعد غير موجود",
-    "User not found" : "المستخدم غير موجود",
-    "Reminder" : "تذكير",
-    "+ Add reminder" : "+ اضافة تذكير",
-    "Select automatic slot" : "إختيار الخانة الزمنية التلقائية",
-    "with" : "مع",
-    "Available times:" : "الأوقات المتاحة:",
-    "Suggestions" : "مقترحات",
-    "Details" : "التفاصيل"
+    "User not found" : "المستخدم غير موجود"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
