@@ -21,6 +21,7 @@ OC.L10N.register(
     "Copy link" : "Copiar enlace",
     "Edit" : "Editar",
     "Delete" : "Borrar",
+    "Calendars" : "Calendarios",
     "New calendar" : "Nuevo calendario",
     "Export" : "Exportar",
     "Empty trash bin" : "Vacíar la papelera",
@@ -77,6 +78,7 @@ OC.L10N.register(
     "Edit event" : "Editar evento",
     "All day" : "Todo el día",
     "Close" : "Cerrar",
+    "Participants" : "Participantes",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
@@ -88,7 +90,6 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "User not found" : "No se encontró el usuario",
-    "Details" : "Detalles"
+    "User not found" : "No se encontró el usuario"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
