@@ -22,22 +22,23 @@ OC.L10N.register(
     "Appointments" : "Plānotās tikšanās",
     "Schedule appointment \"%s\"" : " Ieplānot tikšanos \"%s\"",
     "Schedule an appointment" : "Ieplānot tikšanos",
-    "Prepare for %s" : "Sagatavojieties %s",
+    "Prepare for %s" : "Sagatavojies %s",
     "Follow up for %s" : "Seko līdzi %s",
-    "Your appointment \"%s\" with %s needs confirmation" : "Jūsu tikšanās \"%s\" ar %s nepieciešama apstiprināšana.",
+    "Your appointment \"%s\" with %s needs confirmation" : "Tavai tikšanās \"%s\" ar %s nepieciešama apstiprināšana.",
     "Dear %s, please confirm your booking" : " %s, lūgums apstiprināt savu rezervāciju",
     "Confirm" : "Apstiprināt",
     "This confirmation link expires in %s hours." : "Šī apstiprinājuma saites derīgums beigsies pēc %s stundām.",
     "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ja tomēr ir vēlme atcelt tikšanos, lūgums sazināties ar rīkotāju, atbildot uz šo e-pasta ziņojumu vai apmeklējot tā profilu.",
-    "Your appointment \"%s\" with %s has been accepted" : "Jūsu plānotā tikšanās \"%s\" ar %s ir apstiprināta.",
-    "Dear %s, your booking has been accepted." : " %s, Jūsu rezervācija ir apstiprināta.",
+    "Your appointment \"%s\" with %s has been accepted" : "Tava paredzētā  tikšanās \"%s\" ar %s tika apstiprināta.",
+    "Dear %s, your booking has been accepted." : " %s, Tava rezervācija tika apstiprināta.",
     "Appointment for:" : "Plānota tikšanās:",
     "Date:" : "Datums:",
-    "You will receive a link with the confirmation email" : "Jūs saņemsiet saiti apstiprinājuma e-pastā.",
+    "You will receive a link with the confirmation email" : "Tu saņemsi saiti apstiprinājuma e-pasta ziņojumā",
     "Where:" : "Kur:",
     "Comment:" : "Piebilde:",
     "You have a new appointment booking \"%s\" from %s" : "Jums ir jauna tikšanās rezervācija \"%s\" no %s",
     "Dear %s, %s (%s) booked an appointment with you." : " %s, %s (%s) rezervēja tikšanos ar Jums.",
+    "Location:" : "Atrašanās vieta:",
     "A Calendar app for Nextcloud" : "Nextcloud kalendāra lietotne",
     "Previous day" : "Iepriekšējā diena",
     "Previous week" : "Iepriekšējā nedēļa",
@@ -72,7 +73,7 @@ OC.L10N.register(
     "Edit and share calendar" : "Labot un koplietot kalendāru",
     "Edit calendar" : "Labot kalendāru",
     "An error occurred, unable to create the calendar." : "Atgadījās kļūda, nevar izveidot kalendāru.",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lūdzu, ievadiet derīgu saiti (kas sākas ar http://, https://, webcal:// vai webcals://)",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lūgums ievadīt derīgu saiti (sākas ar http://, https://, webcal:// vai webcals://)",
     "Calendars" : "Kalendāri",
     "Add new" : "Pievienot jaunu",
     "New calendar" : "Jauns kalendārs",
@@ -136,6 +137,7 @@ OC.L10N.register(
     "Share calendar" : "Koplietot kalendāru",
     "Unshare from me" : "Atcelt koplietošanu no manis",
     "Save" : "Saglabāt",
+    "View" : "Skats",
     "Import calendars" : "Ievietot kalendārus",
     "Please select a calendar to import into …" : "Lūgums atlasīt kalendāru, kurā ievietot ...",
     "Filename" : "Datnes nosaukums",
@@ -203,7 +205,7 @@ OC.L10N.register(
     "Visibility" : "Redzamība",
     "Duration" : "Ilgums",
     "Additional calendars to check for conflicts" : "Papildu kalendāri nesaderību pārbaudīšanai",
-    "Pick time ranges where appointments are allowed" : "Izvēlieties laika intervālus, kurās ir atļautas tikšanās.",
+    "Pick time ranges where appointments are allowed" : "Jāizvēlas laika apgabali, kuros ir atļautas tikšanās",
     "to" : "kam",
     "No times set" : "Laiks nav noteikts",
     "Add" : "Pievienot",
@@ -222,8 +224,8 @@ OC.L10N.register(
     "Please confirm your reservation" : "Lūgums apstiprināt savu rezervāciju",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Mēs nosūtījām e-pasta ziņojumu ar informāciju. Lūgums apstiprināt savu tikšanos ar e-pasta ziņojumā esošo saiti. Šo lapu tagad var aizvērt.",
     "Your name" : "Tavs vārds",
-    "Your email address" : "Jūsu e-pasta adrese",
-    "Please share anything that will help prepare for our meeting" : "Lūdzu, dalieties ar visu, kas palīdzēs sagatavoties mūsu sanāksmei",
+    "Your email address" : "Tava e-pasta adrese",
+    "Please share anything that will help prepare for our meeting" : "Lūgums koplietot visu, kas palīdzēs sagatavoties mūsu sanāksmei",
     "Could not book the appointment. Please try again later or contact the organizer." : "Neizdevās pieteikt tikšanos. Lūgums vēlāk mēģināt vēlreiz vai sazināties ar rīkotāju.",
     "Successfully added Talk conversation link to location." : "Talk sarunas saite sekmīgi pievienota atrašanās vietai.",
     "Successfully added Talk conversation link to description." : "Talk sarunas saite sekmīgi pievienota aprakstam.",
@@ -283,7 +285,7 @@ OC.L10N.register(
     "Failed to accept the invitation." : "Neizdevās apstiprināt uzaicinājumu.",
     "The invitation has been declined successfully." : "Uzaicinājums tika sekmīgi noraidīts.",
     "Failed to decline the invitation." : "Neizdevās atteikt uzaicinājumu.",
-    "Your participation has been marked as tentative." : "Jūsu piedalīšanās ir atzīmēta kā nenoteikta.",
+    "Your participation has been marked as tentative." : "Tava piedalīšanās tika atzīmēta kā nenoteikta.",
     "Failed to set the participation status to tentative." : "Neizdevās iestatīt dalības stāvokli kā nenoteiktu.",
     "Accept" : "Pieņemt",
     "Decline" : "Noraidīt",
@@ -345,11 +347,11 @@ OC.L10N.register(
     "to {formattedDate} at {formattedTime}" : "līdz {formattedDate} plkst. {formattedTime}",
     "on {formattedDate} at {formattedTime}" : "{formattedDate} plkst. {formattedTime}",
     "{formattedDate} at {formattedTime}" : "{formattedDate} plkst. {formattedTime}",
-    "Please enter a valid date" : "Lūdzu ievadiet derīgu datumu",
-    "Please enter a valid date and time" : "Lūdzu ievadiet derīgu datumu un laiku",
-    "Please select a time zone:" : "Lūdzu, izvēlieties laika joslu:",
-    "Pick a time" : "Izvēlieties laiku",
-    "Pick a date" : "Izvēlieties datumu",
+    "Please enter a valid date" : "Lūgums ievadīt derīgu datumu",
+    "Please enter a valid date and time" : "Lūgums ievadīt derīgu datumu un laiku",
+    "Please select a time zone:" : "Lūgums atlasīt laika joslu:",
+    "Pick a time" : "Izvēlēties laiku",
+    "Pick a date" : "Izvēlēties datumu",
     "Type to search time zone" : "Rakstīt, lai meklētu laika zonu",
     "Global" : "Globāls",
     "Holidays in {region}" : "Brīvdienas {region}",
@@ -358,7 +360,7 @@ OC.L10N.register(
     "Speak to the server administrator to resolve this issue." : "Jāsazinās ar servera pārvaldītāju, lai atrisinātu šo sarežģījumu.",
     "Subscribed" : "Abonēts",
     "Subscribe" : "Abonēt",
-    "Select slot" : "Izvēlieties laiku",
+    "Select slot" : "Atlasīt laikspraugu",
     "The slot for your appointment has been confirmed" : "Vieta paredzētajam notikumam tika apstiprināta",
     "Appointment Details:" : "Informācija par paredzēto tikšanos:",
     "Time:" : "Laiks:",
@@ -377,6 +379,8 @@ OC.L10N.register(
     "_User requires access to your file_::_Users require access to your file_" : ["Lietotāji pieprasa piekļuvi Tavai datnei","Lietotājs pieprasa piekļuvi Tavai datnei","Lietotāji pieprasa piekļuvi Tavai datnei"],
     "Untitled event" : "Nenosaukts notikums",
     "Close" : "Aizvērt",
+    "Selected" : "Atlasītās",
+    "Participants" : "Dalībnieki",
     "Subscribe to {name}" : "Abonēt {name}",
     "Export {name}" : "Izgūt {name}",
     "Anniversary" : "Gadadiena",
@@ -456,10 +460,6 @@ OC.L10N.register(
     "Imported {filename}" : "Ievietota {filename}",
     "This is an event reminder." : "Šis ir notikuma atgādinājums.",
     "Appointment not found" : "Tikšanās nav atrasta",
-    "User not found" : "Lietotājs nav atrasts",
-    "Reminder" : "Atgādinājums",
-    "+ Add reminder" : "Pievienot atgādinājumu",
-    "Suggestions" : "Ieteikumi",
-    "Details" : "Informācija"
+    "User not found" : "Lietotājs nav atrasts"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
