@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "Коментар:",
     "You have a new appointment booking \"%s\" from %s" : "Имате нов закажан состанок \"%s\" од %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Почитуван/а %s, %s (%s) закажа состанок со вас.",
+    "Location:" : "Локација:",
     "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
     "Previous day" : "Предходен ден",
     "Previous week" : "Предходна недела",
@@ -147,6 +148,7 @@ OC.L10N.register(
     "Share calendar" : "Сподели календар",
     "Unshare from me" : "Не споделувај со мене",
     "Save" : "Зачувај",
+    "View" : "Поглед",
     "Import calendars" : "Увези календари",
     "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
     "Filename" : "Име на датотека",
@@ -404,6 +406,8 @@ OC.L10N.register(
     "Update this occurrence" : "Ажурирајте ја оваа можност",
     "Public calendar does not exist" : "Јавниот календар не постои",
     "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
+    "Remove participant" : "Одстрани учесник",
+    "Create" : "Креирај",
     "from {formattedDate}" : "од {formattedDate}",
     "to {formattedDate}" : "до {formattedDate}",
     "on {formattedDate}" : "на {formattedDate}",
@@ -459,6 +463,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прилог за кој е потребен пристап","Прилози за кои е потребен пристап"],
     "Untitled event" : "Неименуван настан",
     "Close" : "Затвори",
+    "Participants" : "Учесници",
     "Subscribe to {name}" : "Претплатете се на {name}",
     "Export {name}" : "Извези {name}",
     "Show availability" : "Прикажи достапност",
@@ -557,13 +562,6 @@ OC.L10N.register(
     "Imported {filename}" : "Импортирано {filename}",
     "This is an event reminder." : "Ова е потсетник за настан.",
     "Appointment not found" : "Терминот не е пронајден",
-    "User not found" : "Корисникот не е пронајден",
-    "Create a new conversation" : "Креирај нов разговор",
-    "Reminder" : "Потсетник",
-    "+ Add reminder" : "+ Додади потсетник",
-    "with" : "со",
-    "Available times:" : "Достапни термини:",
-    "Suggestions" : "Предлози",
-    "Details" : "Детали"
+    "User not found" : "Корисникот не е пронајден"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
