@@ -12,6 +12,7 @@ OC.L10N.register(
     "This confirmation link expires in %s hours." : "Энэ баталгаажуулах холбоос %s цагийн дараа дуусна ",
     "Date:" : "Огноо:",
     "Where:" : " Хаана:",
+    "Location:" : "Байршил:",
     "A Calendar app for Nextcloud" : "Нэкстклауд Календарь апп ",
     "Previous day" : "Өмнөх өдөр",
     "Previous week" : "Өнмөх 7 хоног",
@@ -28,10 +29,10 @@ OC.L10N.register(
     "Copy link" : "Холбоос хуулах",
     "Edit" : "засварлах",
     "Delete" : "Устгах",
+    "Disable calendar \"{calendar}\"" : "Кадендарь Идэвхигүй болгох \"{calendar}\"",
     "Shared with you by" : "Таньд хуваалцсан",
     "Edit and share calendar" : " Календарь засварлах болон хуваалцах",
     "Edit calendar" : "Календар засварлах",
-    "Disable calendar \"{calendar}\"" : "Кадендарь Идэвхигүй болгох \"{calendar}\"",
     "Add new" : "Шинээр нэмэх",
     "New calendar" : "Шинэ цагийн хуваарь",
     "Export" : "Экспорт",
@@ -49,6 +50,7 @@ OC.L10N.register(
     "Cancel" : "Цуцлах",
     "Actions" : "Үйл ажиллагаа",
     "Show week numbers" : "7 хоногийн дугаарыг харуулах",
+    "Update" : "Шинэчлэх",
     "Location" : "Байршил",
     "Description" : "Тодорхойлолт",
     "to" : "Дуусах нь",
@@ -60,10 +62,12 @@ OC.L10N.register(
     "Friday" : "баасан",
     "Saturday" : "бямба",
     "Sunday" : "ням гариг",
-    "Update" : "Шинэчлэх",
     "Back" : "Буцах",
     "Notification" : "Мэдэгдэл",
     "Email" : "Цахим шуудан",
+    "seconds" : "секунд",
+    "hours" : "хугацаа",
+    "days" : "өдрүүд",
     "Delete file" : "Файл устгах",
     "Available" : "Боломжтой",
     "Unknown" : "Үл танигдах зүйл",
@@ -74,10 +78,11 @@ OC.L10N.register(
     "Repeat" : "Давтах",
     "never" : "хэзээ ч үгүй",
     "after" : "дараа",
+    "Create" : "үүсгэх",
     "Global" : "Нийтийн",
     "Subscribe" : "Захиалга",
     "Personal" : "Хувийн",
-    "Details" : "Дэлгэрэнгүй",
+    "Edit event" : "Үйл явдлыг засварлах",
     "Close" : "Хаах",
     "Week {number} of {year}" : "{year} оны {number}-р долоо хоног ",
     "Daily" : "Өдөр бүр",
