@@ -41,6 +41,8 @@ OC.L10N.register(
     "Comment:" : "Opmerking:",
     "You have a new appointment booking \"%s\" from %s" : "Je hebt een nieuwe afspraakboeking \"%s\" van %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Beste %s, %s (%s) heeft een afspraak met je geboekt.",
+    "Location:" : "Locatie:",
+    "Duration:" : "Duur:",
     "A Calendar app for Nextcloud" : "Een agenda-app voor Nextcloud",
     "Previous day" : "Vorige dag",
     "Previous week" : "Vorige week",
@@ -134,6 +136,7 @@ OC.L10N.register(
     "Could not copy code" : "Kan code niet kopiëren",
     "Delete share link" : "Verwijder deellink",
     "Deleting share link …" : "Verwijderen deellink ...",
+    "{teamDisplayName} (Team)" : "{teamDisplayName}(Team)",
     "An error occurred while unsharing the calendar." : "Er is een fout opgetreden bij het delen van de kalender.",
     "An error occurred, unable to change the permission of the share." : "Er is een fout opgetreden, het is niet mogelijk om de machtiging van de share te wijzigen",
     "can edit" : "kan wijzigen",
@@ -146,6 +149,8 @@ OC.L10N.register(
     "Share calendar" : "Delen kalender",
     "Unshare from me" : "Stop delen met mij",
     "Save" : "Opslaan",
+    "No title" : "Geen titel",
+    "View" : "Bekijken",
     "Import calendars" : "Importeer agenda's",
     "Please select a calendar to import into …" : "Selecteer een agenda om naar te importeren  ...",
     "Filename" : "Bestandsnaam",
@@ -257,11 +262,9 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Kon afspraak niet boeken. Probeer later opnieuw of neem contact op met de organisator.",
     "Back" : "Terug",
     "Book appointment" : "Boek afspraak",
-    "Create a new conversation" : "Maak een nieuw gesprek",
     "Select conversation" : "Selecteer een gesprek",
     "on" : "op",
     "at" : "om",
-    "Reminder" : "Herinnering",
     "before at" : "ervoor om",
     "Notification" : "Melding",
     "Email" : "Email",
@@ -272,7 +275,6 @@ OC.L10N.register(
     "Edit time" : "Bewerk tijd",
     "Save time" : "Bewaar tijd",
     "Remove reminder" : "Verwijder herinnering",
-    "+ Add reminder" : "+ Toevoegen herinnering",
     "Add reminder" : "Voeg herinnering toe",
     "seconds" : "seconden",
     "minutes" : "minuten",
@@ -303,26 +305,25 @@ OC.L10N.register(
     "Awaiting response" : "Wachten op antwoord",
     "Checking availability" : "Beschikbaarheid controleren",
     "Has not responded to {organizerName}'s invitation yet" : "Er is nog niet gereageerd op de uitnodiging van {organizerName}.",
-    "Select automatic slot" : "Selecteer automatisch tijdsblok",
     "chairperson" : "voorzitter",
     "required participant" : "vereiste deelnemer",
     "non-participant" : "geen-deelnemer",
     "optional participant" : "optionele deelnemer",
     "{organizer} (organizer)" : "{organizer} (organizer)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Vrij",
-    "Busy (tentative)" : "Bezig (voorlopig)",
-    "Busy" : "Bezet",
-    "Out of office" : "Niet op kantoor",
-    "Unknown" : "Onbekend",
     "Availability of attendees, resources and rooms" : "Beschikbaarheid van aanwezigen, objecten en ruimtes",
-    "with" : "met",
-    "Available times:" : "Beschikbare tijden:",
     "Suggestion accepted" : "Voorstel geaccepteerd",
+    "Legend" : "Legenda",
+    "Out of office" : "Niet op kantoor",
+    "Attendees:" : "Deelnemers:",
     "Done" : "Klaar",
     "Search room" : "Zoek ruimte",
     "Room name" : "Kamernaam",
     "Check room availability" : "Beschikbaarheid ruimtes controleren",
+    "Free" : "Vrij",
+    "Busy (tentative)" : "Bezig (voorlopig)",
+    "Busy" : "Bezet",
+    "Unknown" : "Onbekend",
     "Find a time" : "Vind een tijdstip",
     "The invitation has been accepted successfully." : "De uitnodiging is succesvol geaccepteerd.",
     "Failed to accept the invitation." : "Aanemen van uitnodiging is mislukt",
@@ -359,7 +360,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Het lukt niet om de gehele-dag instelling aan te passen voor afspraken die onderdeel zijn van een herhaalde-set.",
     "From" : "Van",
     "To" : "Naar",
-    "All day" : "Hele dag",
     "Repeat" : "Herhaling",
     "_time_::_times_" : ["keer","keer"],
     "never" : "geen",
@@ -382,7 +382,7 @@ OC.L10N.register(
     "Does not repeat" : "Niet herhalen",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "De herhaal instelling van deze afspraak wordt niet volledig ondersteund door Nextcloud. Als je de herhaal instellingen wijzigt, gaan bepaalde herhalingen mogelijk verloren.",
     "No rooms or resources yet" : "Nog geen kamers of bronnen",
-    "Suggestions" : "Suggesties",
+    "Resources" : "Bronnen",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} plaats","{seatingCapacity} plaatsen"],
     "Add resource" : "Voeg resource toe",
     "Has a projector" : "Heeft een projector",
@@ -403,6 +403,7 @@ OC.L10N.register(
     "Update this occurrence" : "Deze afspraak bijwerken",
     "Public calendar does not exist" : "Publieke agenda bestaat niet",
     "Maybe the share was deleted or has expired?" : "Mogelijk is het gedeelde item verwijderd of verlopen?",
+    "Create" : "Creëer",
     "from {formattedDate}" : "van {formattedDate}",
     "to {formattedDate}" : "tot {formattedDate}",
     "on {formattedDate}" : "op {formattedDate}",
@@ -426,7 +427,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Geen juiste openbare agenda's ingesteld",
     "Speak to the server administrator to resolve this issue." : "Vraag je beheerder om dit probleem op te lossen.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Openbare feestdagenkalenders worden verstrekt door Thunderbird. Kalendergegevens worden gedownload van {website}.",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Deze openbare agenda's zijn voorgesteld door de beheerder van de server. Agandagegevens worden gedownload van de respectievelijke website.",
     "By {authors}" : "Door {authors}",
     "Subscribed" : "Geabonneerd",
     "Subscribe" : "Abonneren",
@@ -448,19 +448,21 @@ OC.L10N.register(
     "Personal" : "Persoonlijk",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "De automatisch gedetecteerde tijdzone is UTC.\nDit komt waarschijnlijk door beveiligingsmaatregelen van je webbrowser. Stel de tijdzone handmatig in bij de agenda-instellingen.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Je ingestelde tijdzone ({timezoneId}) werd niet gevonden. Er wordt teruggevallen op UTC.\nWijzig je tijdzone in instellingen en meld het incident.",
+    "Edit event" : "Bewerk gebeurtenis",
     "Event does not exist" : "Activiteit bestaat niet",
     "Duplicate" : "Duplicaat",
     "Delete this occurrence" : "Verwijder deze afspraak",
     "Delete this and all future" : "Verwijder deze en toekomstige",
-    "Details" : "Details",
+    "All day" : "Hele dag",
     "Managing shared access" : "Beheren van gedeelde toegang",
     "Deny access" : "Weiger toegang",
     "Invite" : "Uitnodigen",
-    "Resources" : "Bronnen",
     "_User requires access to your file_::_Users require access to your file_" : ["Gebruikers hebben toegang nodig tot uw bestand","Gebruikers hebben toegang nodig tot uw bestand"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Bijlagen die gedeelde toegang vereisen","Bijlagen die gedeelde toegang vereisen"],
     "Untitled event" : "Afspraken zonder naam",
     "Close" : "Sluiten",
+    "Selected" : "Geselecteerd",
+    "Participants" : "Deelnemers",
     "Subscribe to {name}" : "Abonneren op {name}",
     "Export {name}" : "Exporteer {name}",
     "Anniversary" : "Verjaardag",
