@@ -39,6 +39,7 @@ OC.L10N.register(
     "Comment:" : "Comentariu:",
     "You have a new appointment booking \"%s\" from %s" : "Aveți o nouă rezervare \"%s\" de la %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Dragă %s, %s (%s) a rezervat o întâlnire cu tine.",
+    "Location:" : "Locaţie:",
     "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
     "Previous day" : "Ziua anterioară",
     "Previous week" : "Săptămâna anterioară",
@@ -138,6 +139,7 @@ OC.L10N.register(
     "Share calendar" : "Partajează calendarul",
     "Unshare from me" : "Anulare partajarea cu mine",
     "Save" : "Salvează",
+    "View" : "Vizualizare",
     "Import calendars" : "Importă calendare",
     "Please select a calendar to import into …" : "Vă rugăm să selectaţi un calendar în care să importaţi ...",
     "Filename" : "Nume fișier",
@@ -236,11 +238,9 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Te rugăm să împărtășești orice informație ce ne poate ajuta în pregătirea pentru ședința noastră.",
     "Could not book the appointment. Please try again later or contact the organizer." : "Nu s-a putut creea evenimentul. Vă rugăm să încercați mai târziu sau să contactați organizatorul.",
     "Back" : "Înapoi",
-    "Create a new conversation" : "Creează o nouă conversație",
     "Select conversation" : "Selectare conversație",
     "on" : "pe",
     "at" : "la",
-    "Reminder" : "Memento",
     "before at" : "Înainte de la",
     "Notification" : "Notificări",
     "Email" : "Email",
@@ -251,7 +251,6 @@ OC.L10N.register(
     "Edit time" : "Editează ora",
     "Save time" : "Salvează ora",
     "Remove reminder" : "Elimină memento",
-    "+ Add reminder" : "+ Adaugă memento",
     "Add reminder" : "Adaugă memento",
     "seconds" : "secunde",
     "minutes" : "minute",
@@ -278,13 +277,13 @@ OC.L10N.register(
     "Checking availability" : "Se verifică disponibilitatea",
     "Has not responded to {organizerName}'s invitation yet" : "Nu s-a răspuns încă invitației {organizerName}",
     "{organizer} (organizer)" : "{organizer} (organizer)",
+    "Availability of attendees, resources and rooms" : "Disponibilitatea participanților, resurse și camere",
+    "Out of office" : "În afara serviciului",
+    "Done" : "Realizat",
     "Free" : "Liber",
     "Busy (tentative)" : "Ocupat (tetentativ)",
     "Busy" : "Ocupat",
-    "Out of office" : "În afara serviciului",
     "Unknown" : "Necunoscut",
-    "Availability of attendees, resources and rooms" : "Disponibilitatea participanților, resurse și camere",
-    "Done" : "Realizat",
     "The invitation has been accepted successfully." : "Invitația a fost acceptată cu succes.",
     "Failed to accept the invitation." : "Nu s-a acceptat invitația.",
     "The invitation has been declined successfully." : "Invitația a fost refuzată cu succes.",
@@ -313,7 +312,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nu se pot modifica setările zilnice pentru evenimentele care fac parte dintr-un set recurent.",
     "From" : "De la",
     "To" : "Către",
-    "All day" : "Toată ziua",
     "Repeat" : "Repetă",
     "_time_::_times_" : ["dată","ori","ori"],
     "never" : "niciodată",
@@ -336,7 +334,7 @@ OC.L10N.register(
     "Does not repeat" : "Nu se repetă",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definiția recurenței acestui eveniment nu este complet suportată de Nextcloud. Dacă editați opțiunile de recurență, s-ar putea pierde unele recurențe.",
     "No rooms or resources yet" : "Nicio sală sau resursă deocamdată",
-    "Suggestions" : "Sugestii",
+    "Resources" : "Resurse",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} loc","{seatingCapacity} locuri","{seatingCapacity} locuri"],
     "Add resource" : "Adaugă resurse",
     "Has a projector" : "Conține un proiector",
@@ -355,6 +353,9 @@ OC.L10N.register(
     "Update this occurrence" : "Actualizați această ședință",
     "Public calendar does not exist" : "Calendarul public nu există",
     "Maybe the share was deleted or has expired?" : "Poate că partajarea a fost ștearsă sau a expirat?",
+    "Remove participant" : "Elimină participant",
+    "Yes" : "Da",
+    "Create" : "Crează",
     "from {formattedDate}" : "începând cu {formattedDate}",
     "to {formattedDate}" : "până la {formattedDate}",
     "on {formattedDate}" : "pe {formattedDate}",
@@ -392,19 +393,21 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A fost detectată automat zona de timp ca fiind UTC.\nProbabil ca măsura de securitate în cadrul browserului.\nSetați zona de timp manual în setările Calendar.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona de timp ({timezoneId}) nu există. Se revenire la UTC.\nModificați zona de timp în setări și raportați această problemă.",
+    "Edit event" : "Modifică eveniment",
     "Event does not exist" : "Evenimentul nu există",
     "Duplicate" : "Duplicat",
     "Delete this occurrence" : "Șterge această poziție",
     "Delete this and all future" : "Șterge aceasta și toate viitoare",
-    "Details" : "Detalii",
+    "All day" : "Toată ziua",
     "Managing shared access" : "Configurare acces partajat",
     "Deny access" : "Refuză accesul",
     "Invite" : "Invită",
-    "Resources" : "Resurse",
     "_User requires access to your file_::_Users require access to your file_" : ["Utilizatorul necesită acces la fișier","Utilizatorii necesită acces la fișier","Utilizatorii necesită acces la fișier"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Atașament care necesită acces partajat","Atașamente care necesită acces partajat","Atașamente care necesită acces partajat"],
     "Untitled event" : "Eveniment fără titlu",
     "Close" : "Închide",
+    "Title" : "Titlu",
+    "Participants" : "Participanți",
     "Subscribe to {name}" : "Abonare la {name}",
     "Export {name}" : "Exportă {name}",
     "Anniversary" : "Aniversare",
