@@ -20,6 +20,8 @@ OC.L10N.register(
     "Description:" : "Descritzione:",
     "Date:" : "Data:",
     "Where:" : "Ue:",
+    "Location:" : "Positzione:",
+    "Duration:" : "Durata:",
     "A Calendar app for Nextcloud" : "Un'aplicatzione de calendàriu pro Nextcloud",
     "Previous day" : "Die in antis",
     "Previous week" : "Chida in antis",
@@ -98,6 +100,7 @@ OC.L10N.register(
     "No users or groups" : "Peruna utèntzia o grupu",
     "Unshare from me" : "Annulla sa cumpartzidura cun me",
     "Save" : "Sarva",
+    "View" : "Visualiza",
     "Import calendars" : "Importa calendàrios",
     "Please select a calendar to import into …" : "Seletziona unu calendàriu de importare in …",
     "Filename" : "Nùmene de s'archìviu",
@@ -152,7 +155,6 @@ OC.L10N.register(
     "Sunday" : "Domìnigu",
     "Your email address" : "Indiritzu tuo de posta eletrònica",
     "Back" : "In segus",
-    "Create a new conversation" : "Crea una resonada noa",
     "Select conversation" : "Seletziona resonada",
     "on" : "allutu",
     "at" : "a",
@@ -166,7 +168,6 @@ OC.L10N.register(
     "Edit time" : "Modìfica ora",
     "Save time" : "Sarva ora",
     "Remove reminder" : "Boga•nche promemòria",
-    "+ Add reminder" : "+ Agiunghe promemòria",
     "seconds" : "segundos",
     "minutes" : "minutos",
     "hours" : "oras",
@@ -180,13 +181,14 @@ OC.L10N.register(
     "Not available" : "No a disponimentu",
     "{organizer} (organizer)" : "{organizer} (chie organizat)",
     "{attendee} ({role})" : "{attendee} ({role})",
+    "Availability of attendees, resources and rooms" : "Disponibilidade de partetzipantes, resursas e aposentos",
+    "Out of office" : "Foras de serbìtziu",
+    "Attendees:" : "Partetzipadores:",
+    "Room name" : "Nùmene istantza",
     "Free" : "Lìberu",
     "Busy (tentative)" : "Ocupadu (intentu)",
     "Busy" : "Faghende cosa",
-    "Out of office" : "Foras de serbìtziu",
     "Unknown" : "Non connotu",
-    "Availability of attendees, resources and rooms" : "Disponibilidade de partetzipantes, resursas e aposentos",
-    "Room name" : "Nùmene istantza",
     "Accept" : "Atzeta",
     "Decline" : "Refuda",
     "Tentative" : "Intentu",
@@ -208,7 +210,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "No faghet a modificare sa cunfiguratzione de totu sa die pro eventos chi sunt parte de una filera de atividades recurrentes",
     "From" : "Dae",
     "To" : "A",
-    "All day" : "Totu sa die",
     "Repeat" : "Repiti",
     "_time_::_times_" : ["borta","bortas"],
     "never" : "mai",
@@ -231,12 +232,16 @@ OC.L10N.register(
     "Does not repeat" : "No se repitit",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Sa definitzione de recurrèntzia de custu eventu no est suportada dae Nextcloud in manera totale. Si modìficas is optziones de recurrèntzia, calecuna recurrèntzia s'at a pòdere pèrdere.",
     "No rooms or resources yet" : "Ancora peruna istantza o risorsa",
+    "Resources" : "Risorsas",
     "Remove resource" : "Boga·nche risorsa",
     "Search for resources or rooms" : "Chirca risorsas o istantzas",
     "Update this and all future" : "Agiorna custa e is àteras imbenientes",
     "Update this occurrence" : "Agiorna custa ocurrèntzia",
     "Public calendar does not exist" : "Su calendàriu pùblicu no esistit",
     "Maybe the share was deleted or has expired?" : "Mancai sa cumpartzidura est istada cantzellada o est iscadida?",
+    "Remove participant" : " Boga·nche partetzipante",
+    "Yes" : "Si",
+    "Create" : "Crea",
     "from {formattedDate}" : "dae {formattedDate}",
     "to {formattedDate}" : "a {formattedDate}",
     "on {formattedDate}" : "su {formattedDate}",
@@ -260,11 +265,13 @@ OC.L10N.register(
     "Event does not exist" : "S'eventu no esistit",
     "Delete this occurrence" : "Cantzella custa ocurrèntzia",
     "Delete this and all future" : "Cantzella custa e is àteras imbenientes",
-    "Details" : "Detàllios",
+    "All day" : "Totu sa die",
     "Invite" : "Invita",
-    "Resources" : "Risorsas",
     "Untitled event" : "Eventu chene tìtulu",
     "Close" : "Serra",
+    "Selected" : "Seletzionadu",
+    "Title" : "Tìtulu",
+    "Participants" : "Partetzipantes",
     "Subscribe to {name}" : "Sutaiscrie a {name}",
     "Anniversary" : "Anniversàriu",
     "Appointment" : "Apuntamentu",
