@@ -63,7 +63,7 @@ OC.L10N.register(
     "Preview" : "Ko‘rib chiqish",
     "Copy link" : "Havolani nusxalash",
     "Edit" : "Tahrirlash",
-    "Delete" : "Oʻchirish",
+    "Delete" : "O'chirish",
     "Appointment schedules" : "Uchrashuvlar taqvimi",
     "Create new" : "Yangi yaratish",
     "Disable calendar \"{calendar}\"" : "Taqvimni o'chirib qo'yish \"{calendar}\"",
@@ -267,11 +267,9 @@ OC.L10N.register(
     "Add Talk conversation" : "Talk suhbatini qo'shing",
     "Fetching Talk rooms…" : "Muloqot xonalari olinmoqda…",
     "No Talk room available" : "Suhbat xonasi mavjud emas",
-    "Create a new conversation" : "Yangi suhbat yarating",
     "Select conversation" : "Suhbatni tanlang",
     "on" : "da",
     "at" : "ga",
-    "Reminder" : "Eslatma",
     "before at" : "oldin",
     "Notification" : "Bildirishnomalar",
     "Email" : "Email",
@@ -282,7 +280,6 @@ OC.L10N.register(
     "Edit time" : "Vaqtni tahrirlash",
     "Save time" : "Vaqtni saqlash",
     "Remove reminder" : "Eslatmani olib tashlash",
-    "+ Add reminder" : "+ Eslatma qo'shish",
     "Add reminder" : "+ Eslatma qo'shish",
     "seconds" : "sekund",
     "minutes" : "minut",
@@ -317,26 +314,24 @@ OC.L10N.register(
     "Awaiting response" : "Javob kutilmoqda",
     "Checking availability" : "Mavjudligi tekshirilmoqda",
     "Has not responded to {organizerName}'s invitation yet" : " {organizerName}ning taklifiga hali javob bermadi",
-    "Select automatic slot" : "Avtomatik slotni tanlang",
     "chairperson" : "rais",
     "required participant" : "talab qilinadigan ishtirokchi",
     "non-participant" : "qatnashmaydigan",
     "optional participant" : "ixtiyoriy ishtirokchi",
     "{organizer} (organizer)" : "{organizer} (tashkilotchi)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Bepul",
-    "Busy (tentative)" : "Band (taxminan)",
-    "Busy" : "Band",
-    "Out of office" : "Ofisda emas",
-    "Unknown" : "Noma'lum",
     "Availability of attendees, resources and rooms" : "Ishtirokchilar, resurslar va xonalarning mavjudligi",
-    "with" : "bilan",
-    "Available times:" : "Bo`sh vaqtlar:",
     "Suggestion accepted" : "Taklif qabul qilindi",
+    "Legend" : "Ta`rif",
+    "Out of office" : "Ofisda emas",
     "Done" : "Bajarildi",
     "Search room" : "Xonani qidirish",
     "Room name" : "Xona nomi",
     "Check room availability" : "Xona bo`shligini tekshiring",
+    "Free" : "Bepul",
+    "Busy (tentative)" : "Band (taxminan)",
+    "Busy" : "Band",
+    "Unknown" : "Noma'lum",
     "Find a time" : "Vaqt toping",
     "The invitation has been accepted successfully." : "Taklif muvaffaqiyatli qabul qilindi.",
     "Failed to accept the invitation." : "Taklifni qabul qilib bo‘lmadi.",
@@ -375,7 +370,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Takrorlanishlar to‘plamining bir qismi bo‘lgan tadbirlar uchun kun bo‘yi sozlamani o‘zgartirib bo‘lmaydi.",
     "From" : "Dan",
     "To" : "Gacha",
-    "All day" : "Butun kun",
     "Repeat" : "Takrorlash",
     "_time_::_times_" : ["vaqt"],
     "never" : "hech qachon",
@@ -398,7 +392,7 @@ OC.L10N.register(
     "Does not repeat" : "Takrorlanmaydi",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Ushbu hodisaning takrorlanish ta'rifi Nextcloud tomonidan to'liq qo'llab-quvvatlanmaydi. Agar siz takrorlash parametrlarini tahrir qilsangiz, ba'zi takrorlanishlar yo'qolishi mumkin.",
     "No rooms or resources yet" : "Hozircha xonalar yoki manbalar yo'q",
-    "Suggestions" : "Takliflar",
+    "Resources" : "Resurslar",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} joylar"],
     "Add resource" : "Resurs qo'shing",
     "Has a projector" : "Proyektori bor",
@@ -419,6 +413,9 @@ OC.L10N.register(
     "Update this occurrence" : "Ushbu hodisani yangilang",
     "Public calendar does not exist" : "Umumiy taqvim mavjud emas",
     "Maybe the share was deleted or has expired?" : "Ehtimol, ulashish o'chirilgan yoki muddati tugaganmi?",
+    "Yes" : "Ha",
+    "No" : "Yo`q",
+    "Create" : "Yaratish",
     "from {formattedDate}" : " {formattedDate}dan",
     "to {formattedDate}" : " {formattedDate} gacha",
     "on {formattedDate}" : " {formattedDate}da",
@@ -442,7 +439,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Yaroqli umumiy taqvim sozlanmagan",
     "Speak to the server administrator to resolve this issue." : "Ushbu muammoni hal qilish uchun server administratoriga murojaat qiling.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Davlat bayramlari kalendarlari Thunderbird tomonidan taqdim etiladi. Taqvim maʼlumotlari {website}dan yuklab olinadi",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Ushbu ommaviy taqvimlar server administratori tomonidan taklif qilinadi. Taqvim ma'lumotlari tegishli veb-saytdan yuklab olinadi.",
     "By {authors}" : " {authors}tomonidan",
     "Subscribed" : "Obuna boʻlgan",
     "Subscribe" : "Obuna boʻlish",
@@ -469,17 +465,17 @@ OC.L10N.register(
     "Duplicate" : "Nusxa",
     "Delete this occurrence" : "Ushbu tadbirni o'chiring",
     "Delete this and all future" : "Buni va barcha keyingilarini o'chirib tashlang",
+    "All day" : "Butun kun",
     "Modifications wont get propagated to the organizer and other attendees" : "O'zgartirishlar tashkilotchiga va boshqa ishtirokchilarga targ'ib qilinmaydi",
-    "Details" : "Tafsilotlar",
     "Managing shared access" : "Umumiy foydalanishni boshqarish",
     "Deny access" : "Kirishni rad etish",
     "Invite" : "Taklif qiling",
-    "Resources" : "Resurslar",
     "_User requires access to your file_::_Users require access to your file_" : ["Foydalanuvchilar faylingizga kirishni talab qiladi"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Umumiy ruxsatni talab qiluvchi biriktirmalar"],
     "Untitled event" : "Nomsiz tadbir",
     "Close" : "Yopish",
     "Modifications will not get propagated to the organizer and other attendees" : "O'zgartirishlar tashkilotchiga va boshqa ishtirokchilarga targ'ib qilinmaydi",
+    "Title" : "Sarlavha",
     "Subscribe to {name}" : " {name}ga obuna bo'ling",
     "Export {name}" : " {name}eksporti",
     "Show availability" : "Mavjudligini ko'rsatish",
